--- bak_app_voicemail.c	2006-04-11 16:24:46.000000000 -0600
+++ app_voicemail.c	2006-04-27 15:58:00.000000000 -0600
@@ -113,7 +113,7 @@
 #define VM_DELETE		(1 << 12)
 #define VM_ALLOCED		(1 << 13)
 #define VM_SEARCH		(1 << 14)
-
+#define VM_TEMPGREETWARN	(1 << 15)	/*!< Remind user tempgreeting is set */
 #define ERROR_LOCK_PATH		-100
 
 enum {
@@ -454,7 +454,9 @@
 	} else if (!strcasecmp(var,"sendvoicemail")){
 		ast_set2_flag(vmu, ast_true(value), VM_SVMAIL);	
 	} else if (!strcasecmp(var, "review")){
-		ast_set2_flag(vmu, ast_true(value), VM_REVIEW);	
+		ast_set2_flag(vmu, ast_true(value), VM_REVIEW);
+	} else if (!strcasecmp(var, "tempgreetwarn")){
+		ast_set2_flag(vmu, ast_true(value), VM_TEMPGREETWARN);	
 	} else if (!strcasecmp(var, "operator")){
 		ast_set2_flag(vmu, ast_true(value), VM_OPERATOR);	
 	} else if (!strcasecmp(var, "envelope")){
@@ -4032,10 +4034,19 @@
 }
 	
 /* Default English syntax */
-static int vm_intro_en(struct ast_channel *chan,struct vm_state *vms)
-{
+static int vm_intro_en(struct ast_channel *chan, struct ast_vm_user *vmu, struct vm_state *vms)
+ {
+int res;
+/*Prompt that temp greeting is set give option to remove*/
+char prefile[256]="";
+snprintf(prefile,sizeof(prefile), "%s%s/%s/temp", VM_SPOOL_DIR, vmu->context, vms->username);
+	if (ast_test_flag(vmu, VM_TEMPGREETWARN)) {
+		if (ast_fileexists(prefile, NULL, NULL) > 0) {
+			res = ast_play_and_wait(chan,"vm-tempgreetactive");
+		}
+	}
+
 	/* Introduce messages they have */
-	int res;
 	res = ast_play_and_wait(chan, "vm-youhave");
 	if (!res) {
 		if (vms->newmessages) {
@@ -4517,7 +4528,7 @@
 	return res;
 }
 
-static int vm_intro(struct ast_channel *chan,struct vm_state *vms)
+static int vm_intro(struct ast_channel *chan,struct ast_vm_user *vmu,struct vm_state *vms)
 {
 	/* Play voicemail intro - syntax is different for different languages */
 	if (!strcasecmp(chan->language, "de")) {	/* GERMAN syntax */
@@ -4541,7 +4552,7 @@
 	} else if (!strcasecmp(chan->language, "no")) {	/* NORWEGIAN syntax */
 		return vm_intro_no(chan, vms);
 	} else {					/* Default to ENGLISH */
-		return vm_intro_en(chan, vms);
+		return vm_intro_en(chan, vmu, vms);
 	}
 }
 
@@ -5200,7 +5211,7 @@
 		}
 	}
 
-	cmd = vm_intro(chan, &vms);
+	cmd = vm_intro(chan, vmu, &vms);
 
 	vms.repeats = 0;
 	vms.starting = 1;
@@ -5846,6 +5857,7 @@
 	char *send_voicemail;
 	char *astcallop;
 	char *astreview;
+	char *asttempgreetwarn;
 	char *astskipcmd;
 	char *asthearenv;
 	char *astsaydurationinfo;
@@ -6043,6 +6055,16 @@
 		}
 		ast_set2_flag((&globalflags), ast_true(astreview), VM_REVIEW);	
 
+		/*Temperary greeting reminder */
+		if (!(asttempgreetwarn = ast_variable_retrieve(cfg,"general","tempgreetwarn"))){
+			ast_log(LOG_DEBUG,"VM Temperary Greeting Reminder Option disabled globally\n");
+			asttempgreetwarn = "no";
+		}
+		else{
+			ast_log(LOG_DEBUG,"VM Temperary Greeting Reminder Option enabled globally\n");
+		}
+		ast_set2_flag((&globalflags), ast_true(asttempgreetwarn), VM_TEMPGREETWARN);
+
 		if (!(astcallop = ast_variable_retrieve(cfg, "general", "operator"))){
 			ast_log(LOG_DEBUG,"VM Operator break disabled globally\n");
 			astcallop = "no";
